# Copyright (c) 2017-2021 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file

import typing as _typing

from google.protobuf.internal.containers import RepeatedCompositeFieldContainer, RepeatedScalarFieldContainer
from google.protobuf.message import Message as _Message
from google.protobuf.timestamp_pb2 import Timestamp

from .completion_pb2 import Completion
from .ledger_offset_pb2 import LedgerOffset
from .trace_context_pb2 import TraceContext

__all__ = [
    "CompletionStreamRequest",
    "CompletionStreamResponse",
    "Checkpoint",
    "CompletionEndRequest",
    "CompletionEndResponse",
]


class CompletionStreamRequest(_Message):
    ledger_id: str
    application_id: str
    @property
    def parties(self) -> RepeatedScalarFieldContainer[str]: ...
    @property
    def offset(self) -> LedgerOffset: ...
    def __init__(self, *, ledger_id: _typing.Optional[str] = ..., application_id: _typing.Optional[str] = ..., parties: _typing.Optional[_typing.Iterable[str]] = ..., offset: _typing.Optional[LedgerOffset] = ...): ...
    def HasField(self, field_name: _typing.Literal["ledger_id", "application_id", "parties", "offset"]) -> bool: ...
    def ClearField(self, field_name: _typing.Literal["ledger_id", "application_id", "parties", "offset"]) -> None: ...
    def WhichOneof(self, oneof_group: _typing.NoReturn) -> _typing.NoReturn: ...

class CompletionStreamResponse(_Message):
    @property
    def checkpoint(self) -> Checkpoint: ...
    @property
    def completions(self) -> RepeatedCompositeFieldContainer[Completion]: ...
    def __init__(self, *, checkpoint: _typing.Optional[Checkpoint] = ..., completions: _typing.Optional[_typing.Iterable[Completion]] = ...): ...
    def HasField(self, field_name: _typing.Literal["checkpoint", "completions"]) -> bool: ...
    def ClearField(self, field_name: _typing.Literal["checkpoint", "completions"]) -> None: ...
    def WhichOneof(self, oneof_group: _typing.NoReturn) -> _typing.NoReturn: ...

class Checkpoint(_Message):
    @property
    def record_time(self) -> Timestamp: ...
    @property
    def offset(self) -> LedgerOffset: ...
    def __init__(self, *, record_time: _typing.Optional[Timestamp] = ..., offset: _typing.Optional[LedgerOffset] = ...): ...
    def HasField(self, field_name: _typing.Literal["record_time", "offset"]) -> bool: ...
    def ClearField(self, field_name: _typing.Literal["record_time", "offset"]) -> None: ...
    def WhichOneof(self, oneof_group: _typing.NoReturn) -> _typing.NoReturn: ...

class CompletionEndRequest(_Message):
    ledger_id: str
    @property
    def trace_context(self) -> TraceContext: ...
    def __init__(self, *, ledger_id: _typing.Optional[str] = ..., trace_context: _typing.Optional[TraceContext] = ...): ...
    def HasField(self, field_name: _typing.Literal["ledger_id", "trace_context"]) -> bool: ...
    def ClearField(self, field_name: _typing.Literal["ledger_id", "trace_context"]) -> None: ...
    def WhichOneof(self, oneof_group: _typing.NoReturn) -> _typing.NoReturn: ...

class CompletionEndResponse(_Message):
    @property
    def offset(self) -> LedgerOffset: ...
    def __init__(self, *, offset: _typing.Optional[LedgerOffset] = ...): ...
    def HasField(self, field_name: _typing.Literal["offset"]) -> bool: ...
    def ClearField(self, field_name: _typing.Literal["offset"]) -> None: ...
    def WhichOneof(self, oneof_group: _typing.NoReturn) -> _typing.NoReturn: ...



# Copyright (c) 2017-2021 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file

import typing as _typing

from google.protobuf.message import Message as _Message
from google.protobuf.wrappers_pb2 import UInt64Value

__all__ = [
    "TraceContext",
]


class TraceContext(_Message):
    trace_id_high: int
    trace_id: int
    span_id: int
    @property
    def parent_span_id(self) -> UInt64Value: ...
    sampled: bool
    def __init__(self, *, trace_id_high: _typing.Optional[int] = ..., trace_id: _typing.Optional[int] = ..., span_id: _typing.Optional[int] = ..., parent_span_id: _typing.Optional[UInt64Value] = ..., sampled: _typing.Optional[bool] = ...): ...
    def HasField(self, field_name: _typing.Literal["trace_id_high", "trace_id", "span_id", "parent_span_id", "sampled"]) -> bool: ...
    def ClearField(self, field_name: _typing.Literal["trace_id_high", "trace_id", "span_id", "parent_span_id", "sampled"]) -> None: ...
    def WhichOneof(self, oneof_group: _typing.NoReturn) -> _typing.NoReturn: ...



# Copyright (c) 2017-2021 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file

import typing as _typing

from google.protobuf.message import Message as _Message

from .trace_context_pb2 import TraceContext

__all__ = [
    "GetLedgerIdentityRequest",
    "GetLedgerIdentityResponse",
]


class GetLedgerIdentityRequest(_Message):
    @property
    def trace_context(self) -> TraceContext: ...
    def __init__(self, *, trace_context: _typing.Optional[TraceContext] = ...): ...
    def HasField(self, field_name: _typing.Literal["trace_context"]) -> bool: ...
    def ClearField(self, field_name: _typing.Literal["trace_context"]) -> None: ...
    def WhichOneof(self, oneof_group: _typing.NoReturn) -> _typing.NoReturn: ...

class GetLedgerIdentityResponse(_Message):
    ledger_id: str
    def __init__(self, *, ledger_id: _typing.Optional[str] = ...): ...
    def HasField(self, field_name: _typing.Literal["ledger_id"]) -> bool: ...
    def ClearField(self, field_name: _typing.Literal["ledger_id"]) -> None: ...
    def WhichOneof(self, oneof_group: _typing.NoReturn) -> _typing.NoReturn: ...



# Copyright (c) 2017-2021 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file

import typing as _typing

from google.protobuf.message import Message as _Message

from .commands_pb2 import Commands
from .trace_context_pb2 import TraceContext

__all__ = [
    "SubmitRequest",
]


class SubmitRequest(_Message):
    @property
    def commands(self) -> Commands: ...
    @property
    def trace_context(self) -> TraceContext: ...
    def __init__(self, *, commands: _typing.Optional[Commands] = ..., trace_context: _typing.Optional[TraceContext] = ...): ...
    def HasField(self, field_name: _typing.Literal["commands", "trace_context"]) -> bool: ...
    def ClearField(self, field_name: _typing.Literal["commands", "trace_context"]) -> None: ...
    def WhichOneof(self, oneof_group: _typing.NoReturn) -> _typing.NoReturn: ...



# Copyright (c) 2017-2021 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file

import typing as _typing

import grpc as _grpc
from grpc import aio as _grpc_aio

from .participant_pruning_service_pb2 import PruneRequest, PruneResponse

__all__ = [
    "ParticipantPruningServiceStub",
]

_T = _typing.TypeVar('_T')


# noinspection PyAbstractClass
class _Async(_grpc_aio.UnaryUnaryCall, _typing.Awaitable[_T]):
    pass

# noinspection PyAbstractClass
class _AsyncStream(_grpc_aio.UnaryStreamCall, _typing.AsyncIterator[_T]):
    pass


# noinspection PyPep8Naming,DuplicatedCode
class ParticipantPruningServiceStub:
    @classmethod
    @_typing.overload
    def __new__(cls, channel: _grpc.Channel) -> _ParticipantPruningServiceBlockingStub: ...
    @classmethod
    @_typing.overload
    def __new__(cls, channel: _grpc_aio.Channel) -> _ParticipantPruningServiceAsyncStub: ...
    def Prune(self, __1: PruneRequest, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, _typing.Union[str, bytes]], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> _typing.Union[PruneResponse, _Async[PruneResponse]]: ...

# noinspection PyPep8Naming,DuplicatedCode
class _ParticipantPruningServiceBlockingStub(ParticipantPruningServiceStub):
    def Prune(self, __1: PruneRequest, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, _typing.Union[str, bytes]], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> PruneResponse: ...

# noinspection PyPep8Naming,DuplicatedCode
class _ParticipantPruningServiceAsyncStub(ParticipantPruningServiceStub):
    def Prune(self, __1: PruneRequest, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_grpc_aio.Metadata] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> _Async[PruneResponse]: ...



# Copyright (c) 2017-2021 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file

import typing as _typing

from google.protobuf.descriptor import EnumDescriptor
from google.protobuf.message import Message as _Message

from .daml_lf_1_pb2 import Package

__all__ = [
    "ArchivePayload",
    "Archive",
]

class HashFunction:
    DESCRIPTOR: _typing.ClassVar[EnumDescriptor] = ...
    SHA256: _typing.ClassVar[_typing.Literal[0]] = ...
SHA256 = _typing.Literal[0]


class ArchivePayload(_Message):
    minor: str
    @property
    def daml_lf_1(self) -> Package: ...
    @_typing.overload
    def __init__(self, *, minor: _typing.Optional[str] = ...): ...
    @_typing.overload
    def __init__(self, *, minor: _typing.Optional[str] = ..., daml_lf_1: Package = ...): ...
    def HasField(self, field_name: _typing.Literal["minor", "Sum", "daml_lf_1"]) -> bool: ...
    def ClearField(self, field_name: _typing.Literal["minor", "Sum", "daml_lf_1"]) -> None: ...
    def WhichOneof(self, oneof_group: _typing.Literal["Sum"]) -> _typing.Literal[None, "daml_lf_1"]: ...

class Archive(_Message):
    hash_function: _typing.Literal[0]
    payload: bytes
    hash: str
    def __init__(self, *, hash_function: _typing.Optional[_typing.Literal['SHA256', 0]] = ..., payload: _typing.Optional[bytes] = ..., hash: _typing.Optional[str] = ...): ...
    def HasField(self, field_name: _typing.Literal["hash_function", "payload", "hash"]) -> bool: ...
    def ClearField(self, field_name: _typing.Literal["hash_function", "payload", "hash"]) -> None: ...
    def WhichOneof(self, oneof_group: _typing.NoReturn) -> _typing.NoReturn: ...



# Copyright (c) 2017-2021 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file

import typing as _typing

from google.protobuf.descriptor import EnumDescriptor
from google.protobuf.internal.containers import RepeatedScalarFieldContainer
from google.protobuf.message import Message as _Message

from .trace_context_pb2 import TraceContext

__all__ = [
    "ListPackagesRequest",
    "ListPackagesResponse",
    "GetPackageRequest",
    "GetPackageResponse",
    "GetPackageStatusRequest",
    "GetPackageStatusResponse",
]

class PackageStatus:
    DESCRIPTOR: _typing.ClassVar[EnumDescriptor] = ...
    UNKNOWN: _typing.ClassVar[_typing.Literal[0]] = ...
    REGISTERED: _typing.ClassVar[_typing.Literal[1]] = ...
UNKNOWN = _typing.Literal[0]
REGISTERED = _typing.Literal[1]

class HashFunction:
    DESCRIPTOR: _typing.ClassVar[EnumDescriptor] = ...
    SHA256: _typing.ClassVar[_typing.Literal[0]] = ...
SHA256 = _typing.Literal[0]


class ListPackagesRequest(_Message):
    ledger_id: str
    @property
    def trace_context(self) -> TraceContext: ...
    def __init__(self, *, ledger_id: _typing.Optional[str] = ..., trace_context: _typing.Optional[TraceContext] = ...): ...
    def HasField(self, field_name: _typing.Literal["ledger_id", "trace_context"]) -> bool: ...
    def ClearField(self, field_name: _typing.Literal["ledger_id", "trace_context"]) -> None: ...
    def WhichOneof(self, oneof_group: _typing.NoReturn) -> _typing.NoReturn: ...

class ListPackagesResponse(_Message):
    @property
    def package_ids(self) -> RepeatedScalarFieldContainer[str]: ...
    def __init__(self, *, package_ids: _typing.Optional[_typing.Iterable[str]] = ...): ...
    def HasField(self, field_name: _typing.Literal["package_ids"]) -> bool: ...
    def ClearField(self, field_name: _typing.Literal["package_ids"]) -> None: ...
    def WhichOneof(self, oneof_group: _typing.NoReturn) -> _typing.NoReturn: ...

class GetPackageRequest(_Message):
    ledger_id: str
    package_id: str
    @property
    def trace_context(self) -> TraceContext: ...
    def __init__(self, *, ledger_id: _typing.Optional[str] = ..., package_id: _typing.Optional[str] = ..., trace_context: _typing.Optional[TraceContext] = ...): ...
    def HasField(self, field_name: _typing.Literal["ledger_id", "package_id", "trace_context"]) -> bool: ...
    def ClearField(self, field_name: _typing.Literal["ledger_id", "package_id", "trace_context"]) -> None: ...
    def WhichOneof(self, oneof_group: _typing.NoReturn) -> _typing.NoReturn: ...

class GetPackageResponse(_Message):
    hash_function: _typing.Literal[0]
    archive_payload: bytes
    hash: str
    def __init__(self, *, hash_function: _typing.Optional[_typing.Literal['SHA256', 0]] = ..., archive_payload: _typing.Optional[bytes] = ..., hash: _typing.Optional[str] = ...): ...
    def HasField(self, field_name: _typing.Literal["hash_function", "archive_payload", "hash"]) -> bool: ...
    def ClearField(self, field_name: _typing.Literal["hash_function", "archive_payload", "hash"]) -> None: ...
    def WhichOneof(self, oneof_group: _typing.NoReturn) -> _typing.NoReturn: ...

class GetPackageStatusRequest(_Message):
    ledger_id: str
    package_id: str
    @property
    def trace_context(self) -> TraceContext: ...
    def __init__(self, *, ledger_id: _typing.Optional[str] = ..., package_id: _typing.Optional[str] = ..., trace_context: _typing.Optional[TraceContext] = ...): ...
    def HasField(self, field_name: _typing.Literal["ledger_id", "package_id", "trace_context"]) -> bool: ...
    def ClearField(self, field_name: _typing.Literal["ledger_id", "package_id", "trace_context"]) -> None: ...
    def WhichOneof(self, oneof_group: _typing.NoReturn) -> _typing.NoReturn: ...

class GetPackageStatusResponse(_Message):
    package_status: _typing.Literal[0, 1]
    def __init__(self, *, package_status: _typing.Optional[_typing.Literal['UNKNOWN', 0, 'REGISTERED', 1]] = ...): ...
    def HasField(self, field_name: _typing.Literal["package_status"]) -> bool: ...
    def ClearField(self, field_name: _typing.Literal["package_status"]) -> None: ...
    def WhichOneof(self, oneof_group: _typing.NoReturn) -> _typing.NoReturn: ...
